% Units
% Energy : eV
% Temperature : K
% Current : G_Q/e*eV = 2_s*e/h*eV = 77.480917 microampere
% 
% H : Hamiltonian
% GL,GR : coupling matrices of left and right leads
% muL,muR : electrochemical potentials of left and right leads
% T : temperature

function Cur = current(H,GL,GR,muL,muR,T)

CurA = integral(@(E)integrand(E,H,GL,GR,muL,muR,T),...
    -Inf,(muL+muR)/2,...
    'RelTol',1e-12,'AbsTol',1e-18);

CurB = integral(@(E)integrand(E,H,GL,GR,muL,muR,T),...
    (muL+muR)/2,Inf,...
    'RelTol',1e-12,'AbsTol',1e-18);

Cur = CurA + CurB;

end

function I = integrand(E,H,GL,GR,muL,muR,T)

[m,n] = size(E);
I = zeros(m,n);

for i = 1:m
    for j = 1:n
        
        Tra = transmission( H,GL,GR,E(i,j) );
        Tra = abs(Tra);
        
        I(i,j) = Tra*( FDdis(E(i,j),muL,T) - FDdis(E(i,j),muR,T) );
        
    end
end

end