% Units
% Energy : eV
% Time : s
% Temperature : K
% Charge : C
% Current : A

%------------------------------------------------------
% close all;
% clear all;
% clc;

% ---------------------------
% Constants

% electron charge (C)
e = 1.602176565E-19;

% Planck constant (eV*s)
h = 4.135667516E-15;

% current unit : G_Q/e*eV = 2_s*e/h*eV = 77.480917 microampere
C0 = 2*e/h;
% ===========================

% ---------------------------
% Model

% number of modes
M = 4;

% couplings to leads
gamma = 1E-3; % graphene electrode

% energy spacing
dE = -1E-2; % energy spacing of side states
DE = 1; % energy spacing of centre states

% hopping coupling
J = 0.1;

% temperature
T = 300;

% bias voltage
Vsd = 5E-2;

% chemical potentials
muL = Vsd/2;
muR = -Vsd/2;

% gate voltage
% Vg

% lever arm
LAS = 0.2;
LAC = 1;
% ===========================

% ---------------------------
% Matrices

% coupling matrices
GL = zeros(M,M); GL(1,1) = gamma;
GR = zeros(M,M); GR(3,3) = gamma;

% Hamiltonian
H0 = zeros(M,M);
H0(1,2) = J; H0(2,1) = J;
H0(2,3) = J; H0(3,2) = J;
H0(3,4) = J; H0(4,3) = J;
H0(4,1) = J; H0(1,4) = J;

% energy spacing
ES = zeros(M,M);
ES(1,1) = 0.5; ES(3,3) = -0.5;
EC = zeros(M,M);
EC(2,2) = 0.5; EC(4,4) = -0.5;

% gate
gateS = zeros(M,M);
gateS(1,1) = 0.5; gateS(3,3) = -0.5;
gateC = zeros(M,M);
gateC(2,2) = 1; gateC(4,4) = 1;
% ===========================

% ---------------------------
Vgmin = -0.1;
Vgmax = 0.1;
NVg = 201;
Vgaxis = Vgmin + (Vgmax-Vgmin)*(0:NVg-1)/(NVg-1);
Cur = zeros(1,NVg);

for iVg = 1:NVg
    Vg = Vgaxis(iVg);
    
    H = H0 + dE.*ES + DE.*EC + LAS.*Vsd.*gateS + LAC.*Vg.*gateC;
    
    Cur(1,iVg) = current(H,GL,GR,muL,muR,T);
    Cur(1,iVg) = C0*abs(Cur(1,iVg));
    
    iVg
end
% ===========================

% ---------------------------
figure
% hold on
plot(Vgaxis,1E9.*Cur)
% axis([Jmin Jmax 0 8E1])
% set(gca,'XTick',(-0.01:0.005:0.01))
% set(gca,'YTick',(0:2E1:8E1))
set(gca,'YScale','log')
% axis([Vgmin Vgmax 3E-1 3E2])
% set(gca,'XTick',(-0.1:0.05:0.1))
% set(gca,'YTick',10.^(-1:1:3))
set(gca,'LineWidth',1)
set(gca,'FontSize',24)
set(gca,'FontName','Times New Roman')
set(gcf, 'Position', [100 100 600 450])
xlabel('Energy (eV)')
ylabel('Current (nA)')
% ===========================
%======================================================



%======================================================
kB = 8.617332E-5;
iVg = 101;
Cmin = Cur(1,iVg);
CMOSFET = Cmin.*exp(abs(Vgaxis)./(kB*T));

hold on
plot(Vgaxis,1E9.*CMOSFET)
%------------------------------------------------------
