% Units
% Energy : eV
% Time : s
% Temperature : K
% Charge : C
% Current : A

%------------------------------------------------------
% close all;
% clear all;
% clc;

% ---------------------------
% Model

% number of modes
M = 4;

% couplings to leads
gamma = 1E-3; % graphene electrode

% energy spacing
dE = 0; % energy spacing of side states
DE = 1; % energy spacing of centre states

% hopping coupling
J = 0.1;

% gate voltage
Vg = 1E-2;
% ===========================

% ---------------------------
% Matrices

% coupling matrices
GL = zeros(M,M); GL(1,1) = gamma;
GR = zeros(M,M); GR(3,3) = gamma;

% Hamiltonian
H0 = zeros(M,M);
H0(1,2) = J; H0(2,1) = J;
H0(2,3) = J; H0(3,2) = J;
H0(3,4) = J; H0(4,3) = J;
H0(4,1) = J; H0(1,4) = J;

% energy spacing
ES = zeros(M,M);
ES(1,1) = 0.5; ES(3,3) = -0.5;
EC = zeros(M,M);
EC(2,2) = 0.5; EC(4,4) = -0.5;

% gate
gateS = zeros(M,M);
gateS(1,1) = 0.5; gateS(3,3) = -0.5;
gateC = zeros(M,M);
gateC(2,2) = 1; gateC(4,4) = 1;
% ===========================

% ---------------------------
NE = 2001;
Emin = -0.01;
Emax = 0.02;
Eaxis = Emin + (Emax-Emin)*(0:NE-1)/(NE-1);
Tra = zeros(1,NE);

for iE = 1:NE
    E = Eaxis(iE);
    
    H = H0 + dE.*ES + DE.*EC + LAS.*Vsd.*gateS + LAC.*Vg.*gateC;
    
    Tra(1,iE) = transmission(H,GL,GR,E);
end
% ===========================

% ---------------------------
figure
% hold on
plot(Eaxis,abs(Tra))
axis([Emin Emax -0.1 1.1])
set(gca,'XTick',(-0.01:0.01:0.02))
set(gca,'YTick',(-0:0.5:1))
set(gca,'LineWidth',1)
set(gca,'FontSize',24)
set(gca,'FontName','Times New Roman')
set(gcf, 'Position', [100 100 600 450])
xlabel('Transmission')
ylabel('Energy (eV)')
% ===========================
%======================================================
